@@ -136,6 +136,18 @@ class BaseClient:
             logger.error(f"{response.status_code}  {url} {json} failed. {response.text}")
             raise InvalidAPIResponse(f"{response.status_code}  {url} {json} {response.text}")
         return response
+    
+    def delete(self, url: str, json: Dict[str, Any], headers:Optional[Dict[str,str]]=None):
+        if not url.startswith("http"):
+            url = self._get_url_by_caller(url)
+        if self.restriction in ["false",False]:
+            json["restriction"] = "false"
+        json["sessionRestriction"] = "false"
+        response = self.session.delete(url, json=json, headers={**self.headers, **(headers if isinstance(headers, dict) else {})})
+        if response.status_code > 202:
+            logger.error(f"{response.status_code}  {url} {json} failed. {response.text}")
+            raise InvalidAPIResponse(f"{response.status_code}  {url} {json} {response.text}")
+        return response
 
     def project(self, project_id: str) -> "projects.Project":
         return projects.Project.from_project_id(project_id, client=self)
