@@ -54,7 +54,7 @@ class VideoGraph(DeeplabelBase):
     project_id: str
     status: VideoGraphStatus
     progress: int
-    mode: VideoGraphMode
+    mode: Optional[VideoGraphMode] = VideoGraphMode.PROD
     annotated_video: Optional[AnnotatedVideo] = None
 
     @classmethod
@@ -124,7 +124,7 @@ class VideoGraph(DeeplabelBase):
     ):
         request_data = {
             "videoGraphId": self.video_graph_id,
-            "annotatedVideo": {"status": status},
+            "annotatedVideo": {"status": status.value},
         }
         if url is not None:
             request_data["annotatedVideo"]["url"] = url  # type: ignore
